import os
from django.contrib.auth import get_user_model
from django.core.management.base import BaseCommand

class Command(BaseCommand):
    help = "Creates an admin user non-interactively if it doesn't exist"

    def handle(self, *args, **options):
        User = get_user_model()
        if not User.objects.filter(username=os.environ.get("DJANGO_SUPERUSER_USERNAME")).exists():
            User.objects.create_superuser(
                first_name=os.environ.get("DJANGO_SUPERUSER_FIRST_NAME"),
                last_name=os.environ.get("DJANGO_SUPERUSER_LAST_NAME"),
                username=os.environ.get("DJANGO_SUPERUSER_USERNAME"),
                email=os.environ.get("DJANGO_SUPERUSER_EMAIL"),
                password=os.environ.get("DJANGO_SUPERUSER_PASSWORD")
            )
            self.stdout.write(self.style.SUCCESS(f"Successfully created superuser '{os.environ.get('DJANGO_SUPERUSER_USERNAME')}'"))
        else:
            self.stdout.write(self.style.SUCCESS(f"Superuser '{os.environ.get('DJANGO_SUPERUSER_USERNAME')}' already exists"))


"""
Django settings for app project.

Generated by 'django-admin startproject' using Django 3.2.8.

For more information on this file, see
https://docs.djangoproject.com/en/3.2/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/3.2/ref/settings/
"""

from os import environ
from pathlib import Path

# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/3.2/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = 'django-insecure-8m7q7g*!i07%c00r0=mf(97^oyywa_xcpe21d-!j(kfjqhy$$s'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True

if environ.get('DEBUG', "").lower() == 'false':
    DEBUG = False


ALLOWED_HOSTS = ["*"]


# Application definition

INSTALLED_APPS = [
    'baton',
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    "app",
    'rest_framework',
    "compressor",
    'baton.autodiscover',
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'project.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'project.wsgi.application'


# Database
# https://docs.djangoproject.com/en/3.2/ref/settings/#databases

DATABASES = {
}

if DEBUG:
    DATABASES['default'] = {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': BASE_DIR / 'db.sqlite3',
    }
else:
    DATABASES['default'] = {
        'ENGINE': environ.get("SQL_ENGINE", "django.db.backends.postgresql"),
        'NAME': environ.get('SQL_DATABASE'),
        'USER': environ.get('SQL_USER'),
        'HOST': environ.get('SQL_HOST'),
        'PORT': environ.get('SQL_PORT'),
        'PASSWORD': environ.get('SQL_PASSWORD'),
    }


# Password validation
# https://docs.djangoproject.com/en/3.2/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]


# Internationalization
# https://docs.djangoproject.com/en/3.2/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/3.2/howto/static-files/

STATIC_URL = '/static/'
STATIC_ROOT = BASE_DIR / 'static'

# Default primary key field type
# https://docs.djangoproject.com/en/3.2/ref/settings/#default-auto-field

DEFAULT_AUTO_FIELD = 'django.db.models.BigAutoField'

STATICFILES_FINDERS = [
    "compressor.finders.CompressorFinder",
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
    'django.contrib.staticfiles.finders.FileSystemFinder',
]

COMPRESS_PRECOMPILERS = (
    ('text/x-scss', 'django_libsass.SassCompiler'),
)

AUTH_USER_MODEL = 'app.MyUser'

BATON = {
    'SITE_HEADER': 'Admin Site',
    'SITE_TITLE': 'App',
    'INDEX_TITLE': 'Site administration',
    'SUPPORT_HREF': '/contact',
    'COPYRIGHT': 'Copyright © Author',
    'POWERED_BY': 'Author',
    'CONFIRM_UNSAVED_CHANGES': True,
    'SHOW_MULTIPART_UPLOADING': True,
    'ENABLE_IMAGES_PREVIEW': True,
    'CHANGELIST_FILTERS_IN_MODAL': True,
    'CHANGELIST_FILTERS_FORM': True,
    'COLLAPSABLE_USER_AREA': False,
    'MENU_TITLE': 'Menu',
    'MESSAGES_TOASTS': False,
    'GRAVATAR_DEFAULT_IMG': 'retro',
    'LOGIN_SPLASH': '/static/core/img/login-splash.png',
    'SEARCH_FIELD': {
        'label': 'Search contents...',
        'url': '/search/',
    },
    'MENU': (
        {
            'type': 'free',
            "label": "Manage users",
            "children": [
                {
                    "type":"model",
                    "label": "Users",
                    "name": "myuser",
                    "app": "app"
                },
                {
                    "type":"model",
                    "label": "Groups",
                    "name": "group",
                    "app": "auth"
                }
            ]
        },
    )
}

REST_FRAMEWORK = {
    # Use Django's standard `django.contrib.auth` permissions,
    # or allow read-only access for unauthenticated users.
    'DEFAULT_PERMISSION_CLASSES': [
        'rest_framework.permissions.DjangoModelPermissionsOrAnonReadOnly'
    ]
}

EMAIL_HOST = environ.get("EMAIL_HOST")
EMAIL_PORT = environ.get("EMAIL_PORT")

EMAIL_USER = None
EMAIL_PASSWORD = None

if environ.get("EMAIL_AUTH") and environ.get("EMAIL_AUTH").lower() == "true":
    EMAIL_HOST_USER = environ.get("EMAIL_HOST_USER")
    EMAIL_HOST_PASSWORD = environ.get("EMAIL_HOST_PASSWORD")
    EMAIL_USE_TLS = environ.get("EMAIL_USE_TLS").lower() == "true"
    EMAIL_USE_SSL = environ.get("EMAIL_USE_SSL").lower() == "true"



from re import S
from django.shortcuts import render, redirect
from django.contrib.auth import authenticate, login, logout
from django.views.generic import TemplateView
from .forms import CreateUserForm

# Create your views here.
class IndexView(TemplateView):
        template_name = 'app/index.html'

class AboutView(TemplateView):
    template_name = 'app/about.html'

class SignupView(TemplateView):
    template_name = 'app/signup.html'
    def get(self, request, *args, **kwargs):
        if request.user.is_authenticated:
            return render(request, "app/index.html")
        form = CreateUserForm()
        return render(request, self.template_name, {'form': form})

    def post(self, request, *args, **kwargs):
        form = CreateUserForm(request.POST)
        if form.is_valid():
            user = form.save()
            login(request, user)
            return render(request, "app/thanks.html", {'form': form})

        return render(request, self.template_name, {'form': form})

class LoginPageView(TemplateView):
    template_name = 'app/login.html'

    def get(self, request, *args, **kwargs):
        if request.user.is_authenticated:
            return redirect('index')
        return render(request, self.template_name)

    def post(self, request, *args, **kwargs):
        email = request.POST.get('email')
        password = request.POST.get('password')
        user = authenticate(request, email=email, password=password)

        if user is not None:
            login(request, user)
            return redirect('index')

        return render(
            request,
            self.template_name,
            {
                'error_message':
                'Email or password is incorrect'
            }
        )

class LogoutView(TemplateView):
    template_name = 'app/logout.html'

    def get(self, request,  *args, **kwargs):
        logout(request)
        return redirect('index')


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['start_django_project',
 'start_django_project.django-template.code.web',
 'start_django_project.django-template.code.web.app',
 'start_django_project.django-template.code.web.app.management.commands',
 'start_django_project.django-template.code.web.app.migrations',
 'start_django_project.django-template.code.web.project']

package_data = \
{'': ['*'],
 'start_django_project': ['django-template/*',
                          'django-template/.vscode/*',
                          'django-template/code/*',
                          'django-template/nginx/*'],
 'start_django_project.django-template.code.web': ['static/images/*',
                                                   'static/style/*'],
 'start_django_project.django-template.code.web.app': ['templates/*',
                                                       'templates/app/*']}

entry_points = \
{'console_scripts': ['start-django-project = start_django_project.cli:cli']}

setup_kwargs = {
    'name': 'start-django-project',
    'version': '2.1.0',
    'description': 'Init a new django project with a simple bootstrap layout',
    'long_description': '# make-django-app\nTo download:\n\n`pip install make-django-project`\n\nTo use:\n\n`start-django-project ./path_of_your_project`\n\nOr to init inside a folder:\n\n`start-django-project ./`',
    'author': 'TechHeart',
    'author_email': 'contact@TechHeart.co.uk',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)



from django.urls import path, include

from .api_router import router
from .views import IndexView, AboutView, LoginPageView, SignupView, LogoutView

urlpatterns = [
    path('', IndexView.as_view(), name="index"),
    path('about/', AboutView.as_view(), name="about"),
    path('login/', LoginPageView.as_view(), name="loginPage"),
    path('signup/', SignupView.as_view(), name="signup"),
    path('logout/', LogoutView.as_view(), name="logout"),
    path('api/', include(router.urls)),
]

# as
# as


from django.contrib.auth.forms import UserCreationForm
from django import forms
from .models import MyUser

class CreateUserForm(UserCreationForm):
    class Meta:
        model = MyUser
        fields = ['username', 'email', 'password1', 'password2']

    username = forms.CharField(
        label='Username',
        max_length=30,
        required = True,
        widget=forms.TextInput(attrs={'class': 'form-control'})
    )

    email = forms.EmailField(
        label='Email',
        widget=forms.TextInput(attrs={'class': 'form-control'})
    )

    password1 = forms.CharField(
        label='Password',
        widget=forms.PasswordInput(attrs={'class': 'form-control'})
    )

    password2 = forms.CharField(
        label='Password Confirmation',
        widget=forms.PasswordInput(attrs={'class': 'form-control'})
    )